# Define the kmod package name here.
%define kmod_name svec-sw
%define kmods_built svec.ko

%define tagversion 2015-05
%define packageversion %(echo %{tagversion} | sed 's/-/./g')

%define gitversion 0-gf34a4cb

%define sourceversion %(echo %{gitversion} | sed 's/-/./g')

%define fmc_ver 0.1

# If kversion isn't defined on the rpmbuild line, define it here.
%{!?kversion: %define kversion 3.10.0-693.el7.%{_target_cpu}}

Name:    %{kmod_name}-kmod
Version: 0.0
Release: %{packageversion}.%{sourceversion}.1%{?dist}
Group:   System Environment/Kernel
License: GPLv2
Summary: %{kmod_name} kernel module(s)
URL:     http://www.ohwr.org/projects/svec-sw/repository

BuildRequires: perl
BuildRequires: redhat-rpm-config
ExclusiveArch: x86_64

BuildRequires: git
BuildRequires: fmc-kmod-headers = %{fmc_ver}

# for docs
BuildRequires: emacs texinfo-tex

# Sources.
Source0:  %{kmod_name}-%{version}.tar.bz2
Source5:  GPL-v2.0.txt
Source10: kmodtool-%{kmod_name}-el7.sh

Source90: http://www.ohwr.org/attachments/download/3353/svec-bootloader-v3-20140815.bin
Source91: http://www.ohwr.org/attachments/download/3354/svec-bootloader-v3-20140815.bit
Source92: http://www.ohwr.org/attachments/download/3355/svec-bootloader-v3-20140815.mcs

Patch1: svec-sw-fixupmakefile.patch

# Magic hidden here.
%{expand:%(sh %{SOURCE10} rpmtemplate %{kmod_name} %{kversion} "")}

# Disable the building of the debug package(s).
%define debug_package %{nil}

%description
This package provides the %{kmod_name} kernel module(s).
It is built to depend upon the specific ABI provided by a range of releases
of the same variant of the Linux kernel and not on any one specific build.

%package headers
Summary: Kernel headers for %{kmod_name}

%description headers
Kernel headers for %{kmod_name}-kmod

%package tools
Summary: Userspace utilities for %{kmod_name}
Requires:	%{kmod_name}-kmod = %{version}

%description tools
Tools for %{kmod_name}-kmod

%prep
%setup -q -n %{kmod_name}-%{version}
for thiskmod in %{kmods_built}; do
    echo "override ${thiskmod} * weak-updates/%{kmod_name}" >> kmod-%{kmod_name}.conf
done

GIT_VERSION=$(git describe --dirty --long --tags)

cat << EOF > svec-sw-version-env
GIT_VERSION=${GIT_VERSION}
SVEC_SW_VERSION=${GIT_VERSION}
EOF

%patch1 -p1

%build
KSRC=%{_usrsrc}/kernels/%{kversion}
FMC_HEADERS='/usr/src/kmods/fmc-%{fmc_ver}'

### ay
source ${FMC_HEADERS}/fmc-version-env
###

%{__cp} ${FMC_HEADERS}/Module.symvers kernel/

pushd kernel
%{__make} LINUX="${KSRC}" FMC_BUS=${FMC_HEADERS} FMC_BUS_VERSION=${FMC_BUS_VERSION}
popd

# Cleanup the mappings
for line in $(cat kernel/modules.order); do
  kmod=$(basename ${line})
  echo "kernel/extra/${kmod}" >> kernel/svec-sw.order
done

awk '{print $1 "\t" $2 "\textra/fmc\t" $4}' kernel/Module.symvers > kernel/svec-sw.symvers


# Build application tools
pushd tools
%{__make} %{?_smp_mflags}
popd

# Build docs
#pushd doc
#%{__make} %{?_smp_mflags}
#popd



%install
# Setup headers
%{__install} -d %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/linux
echo "%{tagversion}-%{gitversion}" > %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/version
%{__install} svec-sw-version-env %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/svec-sw-version-env

%{__install} kernel/svec-sw.order %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/modules.order
%{__install} kernel/svec-sw.symvers %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/Module.symvers
for filename in $(cd kernel ; find . -type f -name \*.h); do
    %{__install} -D kernel/${filename} %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/linux/${filename}
done

# install tools
%{__install} -d %{buildroot}%{_sbindir}
%{__install} tools/svec-config %{buildroot}%{_sbindir}/
%{__install} tools/svec-wrc-loader %{buildroot}%{_sbindir}/

%{__install} -d %{buildroot}/lib/firmware/fmc/
%{__install} %{SOURCE90} %{buildroot}/lib/firmware/fmc/
%{__install} %{SOURCE91} %{buildroot}/lib/firmware/fmc/
%{__install} %{SOURCE92} %{buildroot}/lib/firmware/fmc/

%{__install} -d %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
for thiskmod in %{kmods_built}; do
    %{__install} kernel/${thiskmod} %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
done
%{__install} -d %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} kmod-%{kmod_name}.conf %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} -d %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/
%{__install} %{SOURCE5} %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/

%{__install} kernel/svec-sw.order %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/modules.order
%{__install} kernel/svec-sw.symvers %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/Module.symvers


# strip the modules(s)
find %{buildroot} -type f -name \*.ko -exec %{__strip} --strip-debug \{\} \;

# Sign the modules(s)
%if %{?_with_modsign:1}%{!?_with_modsign:0}
# If the module signing keys are not defined, define them here.
%{!?privkey: %define privkey %{_sysconfdir}/pki/SECURE-BOOT-KEY.priv}
%{!?pubkey: %define pubkey %{_sysconfdir}/pki/SECURE-BOOT-KEY.der}
for module in $(find %{buildroot} -type f -name \*.ko);
do %{__perl} /usr/src/kernels/%{kversion}/scripts/sign-file \
sha256 %{privkey} %{pubkey} $module;
done
%endif

%clean
%{__rm} -rf %{buildroot}

%files tools
%defattr(0644,root,root,0755)
%docdir %{_defaultdocdir}/svec-sw-%{version}
# management tools either make use of dev nodes with
#  group dialout, or outright calls to the kernel
%attr(4750, root, dialout) %{_sbindir}/*

%files headers
%defattr(0644,root,root,0755)
%{_usrsrc}/kmods/%{kmod_name}-%{version}


%changelog
* Tue Aug 29 2017 Akemi Yagi<toracat@elrepo.org> - 0.0-2015.05.0.gf34a4cb.1
- Initial el7 build of the kmod package
- Submitted by jcpunk [elrepo bug #688]
